pub struct CreateTaskResult {
pub result_type: String,
pub task: Task,
pub meta: HashMap<String, Value>,
}Expand description
Task-shaped result returned in place of an immediate tool result.
Fields
result_type: Stringtask: Taskmeta: HashMap<String, Value>Trait Implementations
Sourceimpl Clone for CreateTaskResult
impl Clone for CreateTaskResult
Sourcefn clone(&self) -> CreateTaskResult
fn clone(&self) -> CreateTaskResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateTaskResult
impl Debug for CreateTaskResult
Sourceimpl<'de> Deserialize<'de> for CreateTaskResult
impl<'de> Deserialize<'de> for CreateTaskResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CreateTaskResult
impl PartialEq for CreateTaskResult
Sourcefn eq(&self, other: &CreateTaskResult) -> bool
fn eq(&self, other: &CreateTaskResult) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CreateTaskResult
impl Serialize for CreateTaskResult
impl StructuralPartialEq for CreateTaskResult